Crate rialo_limits

Crate rialo_limits 

Re-exports

pub use rex::update_size::*;

Modules

rex

Constants

MAX_COMPUTE_UNIT_LIMIT
MAX_CONSENSUS_BLOCK_SIZE
The maximum size of a consensus block in bytes.
MAX_HEAP_FRAME_BYTES
MAX_INSTRUCTION_DATA_SIZE
The maximum size of a program instruction payload in bytes.
MAX_RESPONSE_SIZE
The maximum size for a payload received from a remote backend in bytes.
MAX_STATIC_ACCOUNTS_PER_PACKET
MAX_TRANSACTION_SIZE
The maximum size of a single transaction in bytes.
PACKET_DATA_SIZE
The size of the data portion of a network packet in bytes. Note: Maximum over-the-wire size of a Transaction 1280 is IPv6 minimum MTU 40 bytes is the size of the IPv6 header 8 bytes is the size of the fragment header
_MAX_BUILTIN_ALLOCATION_COMPUTE_UNIT_LIMIT