Re-exports
pub use rex::update_size::*;
Modules
Constants
- MAX_
COMPUTE_ UNIT_ LIMIT - MAX_
CONSENSUS_ BLOCK_ SIZE - The maximum size of a consensus block in bytes.
- MAX_
HEAP_ FRAME_ BYTES - MAX_
INSTRUCTION_ DATA_ SIZE - The maximum size of a program instruction payload in bytes.
- MAX_
RESPONSE_ SIZE - The maximum size for a payload received from a remote backend in bytes.
- MAX_
STATIC_ ACCOUNTS_ PER_ PACKET - MAX_
TRANSACTION_ SIZE - The maximum size of a single transaction in bytes.
- PACKET_
DATA_ SIZE - The size of the data portion of a network packet in bytes. Note: Maximum over-the-wire size of a Transaction 1280 is IPv6 minimum MTU 40 bytes is the size of the IPv6 header 8 bytes is the size of the fragment header
- _MAX_
BUILTIN_ ALLOCATION_ COMPUTE_ UNIT_ LIMIT