Crate rialo_limits

Crate rialo_limits 

Constants

MAX_CONSENSUS_BLOCK_SIZE
The maximum size of a consensus block in bytes.
MAX_INSTRUCTION_DATA_SIZE
The maximum size of a program instruction payload in bytes.
MAX_ORACLE_OUTPUT_SIZE
MAX_RESPONSE_SIZE
The maximum size for a payload received from a remote backend in bytes.
MAX_STATIC_ACCOUNTS_PER_PACKET
MAX_TRANSACTION_SIZE
The maximum size of a single transaction in bytes.
MIN_VIABLE_LIMIT_OF_ORACLE_OUTPUT_SIZE
The minimum viable size for the oracle output buffer, ensuring the oracle can serialize and distinguish success or error responses from the OracleOutput enum without truncation. Chosen empirically to support a variety of error/success reporting formats.
ORACLE_OUTPUT_RAW_BASE_OVERHEAD
ORACLE_REPORT_BASE_OVERHEAD
ORACLE_UPDATE_BASE_OVERHEAD
PACKET_DATA_SIZE
Maximum over-the-wire size of a Transaction 1280 is IPv6 minimum MTU 40 bytes is the size of the IPv6 header 8 bytes is the size of the fragment header

Functions

max_oracle_output_serialized_bytes
Calculates the maximum size of serialized OracleOutput.